@@ -241,7 +241,7 @@ def plot(mode, all_para_combination={}, subchart_settings={}, number_of_curves=2
         }
 
     if mode == 'equity_curves':
-        result_df = pd.read_csv('backtest_result.csv', index_col=0)
+        result_df = pd.read_csv('backtest_result.csv', index_col=0, low_memory=False)
         app = equity_curves.Plot(all_para_combination, result_df, subchart_settings, number_of_curves)
 
     if mode == 'aggregate':
