@@ -22,6 +22,7 @@ class Plot:
     chart_type = 1
     relayoutData = []
     init = True
+    select_all_status = False
     save_path = ''
     initial_capital = 0
     return_in_capital = 0
@@ -73,7 +74,7 @@ class Plot:
         self.year_list = list(range(start_date_year, end_date_year + 1))
 
         empty_line_chart = components.empty_line_chart()
-        checkbox_div = components.update_checkbox_div(para_dict, result_df)
+        checkbox_div, code_list = components.update_checkbox_div(para_dict, result_df)
         col_df = result_df.columns.values.tolist()
         df_col = pd.DataFrame([['-----' for column in col_df]], columns=col_df)
         performance_matrix = components.update_performance_matrix(start_date, end_date, df_col.iloc[0].copy(), para_dict, '-----', '-----')
@@ -489,6 +490,20 @@ class Plot:
 
             # Sort Method Selected, generate Chart 1
             if sort_method:
+                for para in para_checklist:
+                    if para == []:
+                        fig_line = components.empty_line_chart()
+                        # Disable Chart 2
+                        chart2_button_text = 'Strategy Analysis >'
+                        self.chart_type = 1
+                        hist_style = {'display': 'none'}
+
+                        return fig_line, filter_div, filter_dropdown_div, filter_input_div, _add_button_style, \
+                            None, chart1_button_text, chart2_button_text, hist_area, hist_style, \
+                            main_chart_area_style, chart3_dashboard_style, chart3_area_style, \
+                            chart3_start_str, chart3_end_str, chart3_chart
+
+
                 current_df = result_df.copy()
 
                 # Filter according to the filer list
@@ -627,6 +642,28 @@ class Plot:
             return performance_matrix, button_style
 
 
+        # Select All Button
+        @app.callback(
+            Output({'type': 'para-checklist', 'index': ALL}, 'value'),
+            [Input("all-or-none", "value")],
+            State({'type': 'para-checklist', 'index': ALL}, 'value'),
+        )
+        def select_all_none(selected_all, options):
+
+            if selected_all == None:
+                pass
+            elif selected_all == ['All']:
+                if self.select_all_status == False:
+                    options[0] = code_list
+                    self.select_all_status = True
+            else:
+                if self.select_all_status == True:
+                    options[0] = []
+                    self.select_all_status = False
+
+            return options
+
+
         # Save Button
         @app.callback(
             Output('save_status', "children"),
